@@ -3,9 +3,9 @@ import sys
 from pprint import pprint
 from datetime import datetime
 
-from criteo_api_retailmedia_preview.api.analytics_api import AnalyticsApi
-from criteo_api_retailmedia_preview.models import StatisticsReportQueryMessage
-from criteo_api_retailmedia_preview import Configuration, ApiClient
+from criteo_api_retailmedia_v2022_04.api.analytics_api import AnalyticsApi
+from criteo_api_retailmedia_v2022_04.models import StatisticsReportQueryMessage
+from criteo_api_retailmedia_v2022_04 import Configuration, ApiClient
 
 if __name__ == '__main__':
     if len(sys.argv) != 3:
